# @ui/openapi

Generate @ui/app needed API client and form data from OpenAPI V2.

- [Motivation](#motivation)
  - [TL;DR](#tldr)
- [Codegen](#codegen)
  - [Client](#client)
  - [formik](#formik)
- [How to contribute](#how-to-contribute)
- [License](#license)

## Motivation

RFC: [OpenAPI to TypeScript API Client and Forms](https://github.com/chaos-mesh/rfcs/pull/30)

We recommend that you read the RFC to understand the motivation for writing this package,
but if you just want a quick overview, see the **TL;DR** below:

### TL;DR

This package mainly solves the problem of **code synchronization** and **duplicate type definition** between
front-end and back-end by automatically generating code.

We will use the `codegen` command to accomplish this task.

## Codegen

Run `yarn workspace @ui/openapi codegen -h` to see the usage of codegen:

```console
codegen.js [command]

Commands:
  codegen.js client  generate API client by @openapitools/openapi-generator-cli
  codegen.js formik  convert the definitions generated by @openapitools/openapi-generator-cli to Formik form data
```

### Client

This command will call `@openapitools/openapi-generator-cli` to generate `typescript-axios` API client
which is described in <https://openapi-generator.tech/docs/generators/typescript-axios/>.

We will use the copy of `swagger.yaml` in `pkg/dashboard/swaggerdocs` as input.
At the end of the generation, this file will be deleted.

The output destination is `ui/app/src/openapi`. You can view the files in it for more details.

### formik

In this command, we will use the API client generated by `client` to generate `Formik` form data.

The output destination is `ui/app/src/formik`. Here is an example of what is generated:

```ts
// AWSChaos

/**
 * This file was auto-generated by @ui/openapi.
 * Do not make direct changes to the file.
 */

export const actions = ['ec2-stop', 'ec2-restart', 'detach-volume'],
  data = [
    {
      field: 'text',
      label: 'awsRegion',
      value: '',
      helperText: 'AWSRegion defines the region of aws.',
    },
    {
      field: 'text',
      label: 'deviceName',
      value: '',
      helperText: 'Optional. DeviceName indicates the name of the device. Needed in detach-volume.',
      when: "action=='detach-volume'",
    },
    {
      field: 'text',
      label: 'ec2Instance',
      value: '',
      helperText: 'Ec2Instance indicates the ID of the ec2 instance.',
    },
    {
      field: 'text',
      label: 'secretName',
      value: '',
      helperText: 'Optional. SecretName defines the name of kubernetes secret.',
    },
    {
      field: 'text',
      label: 'volumeID',
      value: '',
      helperText: 'Optional. EbsVolume indicates the ID of the EBS volume. Needed in detach-volume.',
      when: "action=='detach-volume'",
    },
  ]
```

We will use the `actions` and `data` fields to render the form in the interface.

## How to contribute

Pull a request or open an issue to describe your changes or problems.

The recommended PR/Issue title format is `xxx(@ui/openapi): xxx`.

## License

Same as Chaos Mesh
